package de.juplo.yourshouter;



import javax.inject.Inject;

import org.springframework.context.annotation.Configuration;
import org.springframework.social.connect.UsersConnectionRepository;
import org.springframework.web.servlet.config.annotation.EnableWebMvc;
import org.springframework.web.servlet.config.annotation.InterceptorRegistry;
import org.springframework.web.servlet.config.annotation.ViewControllerRegistry;
import org.springframework.web.servlet.config.annotation.WebMvcConfigurerAdapter;


/**
 * Spring MVC Configuration.
 *
 * @author Kai Moritz
 */
@Configuration
@EnableWebMvc
public class WebMvcConfig extends WebMvcConfigurerAdapter
{
  @Inject
  private UsersConnectionRepository usersConnectionRepository;


  /**
   * Configure the {@link UserCookieInterceptor} to intercept all requests.
   *
   * @param registry
   *     The {@link InterceptorRegistry} to use.
   *
   * @see {@link UserCookieInterceptor}
   */
  @Override
  public void addInterceptors(InterceptorRegistry registry)
  {
    registry.addInterceptor(new UserCookieInterceptor(usersConnectionRepository));
  }

  /**
   * {@inheritDoc}
   */
  @Override
  public void addViewControllers(ViewControllerRegistry registry)
  {
    // Configure the view /thymeleaf/signin.html for the path /signin.html
    registry.addViewController("/signin.html");
  }
}
